import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { PowerScrollView } from '@antmjs/vantui';

export default (props) => {
  const { request, params, renderItem, onLoadingChange } = props;

  const pageSize = 20;
  const pageNumRef = React.useRef(1);
  const listRef = React.useRef([]);
  const [loading, setLoading] = React.useState(false);
  const [list, setList] = React.useState([]);
  const [finished, setFinished] = React.useState(true);
  listRef.current = list;

  const changeLoading = (val) => {
    setLoading(val);
    if (onLoadingChange) {
      onLoadingChange(val);
    }
  }

  const queryData = React.useCallback((options = {}) => {
    return new Promise((resolve, reject) => {
      changeLoading(true);
      request({
        pageSize,
        ...(params || {}),
        ...options
      }).then((res) => {
        const { records, current, pages } = res;

        if (current == 1) {
          setList(records || []);
        } else {
          setList(listRef.current.concat(records || []));
        }

        setFinished(current >= pages);
        changeLoading(false);
        resolve();
      }).catch((err) => {
        changeLoading(false);
        reject(err);
      });
    });
  }, [request, params]);

  const onScrollToLower = React.useCallback((event = 0, isRefresh = false) => {
    pageNumRef.current += 1;
    return queryData({pageNum : pageNumRef.current});
  }, [queryData]);

  React.useEffect(() => {
    pageNumRef.current = 1;
    queryData({pageNum : pageNumRef.current});
  }, [queryData]);
  
  return (
    <PowerScrollView
      scrollY
      finishedText="没有更多了"
      refresherEnabled={false}
      current={list.length}
      pageSize={pageSize}
      finished={finished}
      onScrollToLower={onScrollToLower}
    >
      {
        list.map(renderItem)
      }
    </PowerScrollView>
  )
}
