import React from 'react';
import Taro from '@tarojs/taro';
import { View, Map } from '@tarojs/components';
import { getLocation } from '@/utils/authorize';
import iconPath from '@/assets/icons/marker.png';
import style from './style.module.less';

// location 逻辑
// 如果 props.location 有值, 那么放弃地图定位的点, 使用 props.location
// 否则使用 地图定位的点
// 如果地图定位失败 或者 props.location 为空, 那么不产生数据交互
// 但是地图上默认使用 霍山县人民政府 的定位
export default (props) => {
  const { location, onLocChange } = props;

  const [currentPos, setCurPos] = React.useState();
  const [
    markers,
    lngLat,
  ] = React.useMemo(() => {
    const loc = location || currentPos || '116.354259,31.415587';    
    const [longitude, latitude] = loc.split(',');

    const mks = [{
      id: 1,
      longitude,
      latitude,
      iconPath,
      width: 17,
      height: 20
    }];

    return [
      mks,
      [longitude, latitude]
    ]
  }, [location, currentPos]);
  
  React.useEffect(() => {
    getLocation().then((res) => {
      setCurPos([res.longitude, res.latitude].join(','));
    }).catch((err) => {
      console.error(err);
      Taro.showToast({
        title: '定位失败',
        icon: 'none',
      })
    });
  }, []);

  React.useEffect(() => {
    if (!location && !currentPos) return;

    const loc = location || currentPos;
    if (loc) {
      onLocChange(loc);
    }
  }, [location, currentPos]);
  
  return (
    <View className={style['map-wrapper']}>
      <Map
        longitude={lngLat[0]}
        latitude={lngLat[1]}
        markers={markers}
      ></Map>
    </View>
  )
}
