import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { CellGroup, Cell, Field, RadioGroup, Radio } from '@antmjs/vantui';
import Map from '@/components/map';
import { getTaCheckItemAnswer } from '@/services/tacheckitem';
import mapIcon from '@/assets/icons/marker.png';
import AgePicker from './AgePicker';

export default (props) => {
  const { checkItemInfo, checkType, answer, readonly, onChange, onLoadingChange } = props;

  const [loc, setLoc] = React.useState();
  const [showAgePicker, setShowAgePicker] = React.useState(false);

  const setLoading = (v) => {
    if (onLoadingChange) {
      onLoadingChange(v)
    }
  }
  
  const setFieldChange = (key, val) => {
    onChange({
      location: loc,
      ...answer || {},
      [key]: val,
    })
  }

  // // 获取答题主记录信息
  // React.useEffect(() => {
  //   if (checkItemInfo?.itemId) {
  //     setLoading(true);
  //     getTaCheckItemAnswer(checkItemInfo?.itemId).then((res) => {
  //       if (res) {
  //         onChange(res);
  //       }
  //       setLoading(false);
  //     }).catch(() => {
  //       setLoading(false);
  //     });
  //   }
  // }, [checkItemInfo?.itemId])
  
  return (
    <View>
      <Map location={answer?.location} onLocChange={setLoc} />
      <CellGroup>
        {
          checkType == 'loc' && (
            <Cell
              title="点位"
              value={checkItemInfo?.name}
            />
          )
        }
        <Field
          readonly={readonly}
          placeholder={checkType == 'loc' ? '请输入地址' : '请填写小区名称'}
          value={answer?.addr}
          leftIcon={mapIcon}
          onChange={e => setFieldChange('addr', e.detail)}
        />
      </CellGroup>
      {
        checkType == 'survey' && (
          <CellGroup style={{marginTop: '20px'}}>
            <Cell title="性别">
              <View style={{textAlign: 'right'}}>
                <RadioGroup
                  disabled={readonly}
                  direction="horizontal"
                  value={answer?.sex}
                  style={{display: 'inline-flex'}}
                  onChange={(e) => setFieldChange('sex', e.detail)}
                >
                  <Radio name="1" checkedColor="var(--main-bg-color)">男</Radio>
                  <Radio name="2" checkedColor="red">女</Radio>
                </RadioGroup>
              </View>
            </Cell>
            <Cell
              title="年龄"
              isLink
              value={answer?.age}
              onClick={() => !readonly && setShowAgePicker(true)}
            />
            <AgePicker
              show={showAgePicker}
              onShowChange={setShowAgePicker}
              onChange={(e) => setFieldChange('age', e)}
            />
          </CellGroup>
        )
      }
    </View>
  )
}
